// naumann@stce.rwth-aachen.de

#include <Eigen/Dense>
using VT=Eigen::VectorX<double>;

#include <cmath>
#include <cassert>
#include <fstream>
#include <iostream>
using namespace std;

double f(double p, double x) {
  assert(x>=0);
  return p*x;
}

double e(double p, VT xobs, VT yobs) {
  assert(xobs.size()==yobs.size());
  double e=0;
  int i=0;
  while (i<xobs.size()) {
    e=e+pow(f(p,xobs(i))-yobs(i),2);
    i=i+1;
  }
  return e;
}

double fit(VT xobs, VT yobs) {
  assert(xobs.size()==yobs.size());
  return yobs.dot(xobs)/xobs.dot(xobs);
}

int main() {
  double p=0.5;
  int nobs=5;
  VT xobs=VT::Random(nobs); 
  xobs=xobs.cwiseProduct(xobs); 
  VT yobs=VT::Random(nobs); 
  ofstream ofs("data");
  int i=0;
  while (i<nobs) {
    ofs << xobs(i) << ' ' << yobs(i) << endl;
    i=i+1;
  }
  cout << "p=" << p << endl;
  cout << "e=" << e(p,xobs,yobs) << endl;
  p=fit(xobs,yobs);
  cout << "p=" << p << endl;
  cout << "e=" << e(p,xobs,yobs) << endl;
  return 0;
}
